Bug 775624 Part 16 - Convert NS_INLINE_IS_BREAK_BEFORE to a method. r?dholbert draft
authorTing-Yu Lin <tlin@mozilla.com>
Tue, 14 Feb 2017 16:05:24 +0800
changeset 488479 1d53e1475846e798666f8e5d863cdbf9cb6acd1a
parent 488478 901a780c62a8a39cac80ed831c55707cff360444
child 488480 03aae68507dbaf19f99edb2377abe0ed1723f464
push id46538
push userbmo:tlin@mozilla.com
push dateThu, 23 Feb 2017 05:39:06 +0000
reviewersdholbert
bugs775624
milestone54.0a1
Bug 775624 Part 16 - Convert NS_INLINE_IS_BREAK_BEFORE to a method. r?dholbert MozReview-Commit-ID: 8vxRpqbZNnk
layout/forms/nsComboboxControlFrame.cpp
layout/generic/BlockReflowInput.cpp
layout/generic/nsBlockFrame.cpp
layout/generic/nsBlockReflowContext.cpp
layout/generic/nsContainerFrame.cpp
layout/generic/nsFirstLetterFrame.cpp
layout/generic/nsGridContainerFrame.cpp
layout/generic/nsIFrame.h
layout/generic/nsInlineFrame.cpp
layout/generic/nsLineLayout.cpp
layout/generic/nsRubyBaseContainerFrame.cpp
layout/generic/nsRubyFrame.cpp
layout/reftests/css-grid/grid-fragmentation-006-ref.html
layout/reftests/css-grid/grid-fragmentation-006.html
layout/reftests/css-grid/grid-fragmentation-007.html
layout/reftests/css-grid/grid-fragmentation-019.html
layout/reftests/css-grid/grid-fragmentation-022.html
layout/reftests/css-grid/grid-fragmentation-023.html
layout/reftests/css-grid/grid-fragmentation-024.html
layout/reftests/css-grid/grid-fragmentation-025.html
layout/reftests/css-grid/grid-fragmentation-027.html
layout/reftests/css-grid/grid-fragmentation-028.html
layout/reftests/css-grid/grid-fragmentation-030-ref.html
layout/reftests/css-grid/grid-fragmentation-030.html
layout/reftests/css-grid/grid-fragmentation-031-ref.html
layout/reftests/css-grid/grid-fragmentation-031.html
layout/tables/nsTableFrame.cpp
layout/tables/nsTableRowGroupFrame.cpp
--- a/layout/forms/nsComboboxControlFrame.cpp
+++ b/layout/forms/nsComboboxControlFrame.cpp
@@ -892,17 +892,17 @@ nsComboboxControlFrame::Reflow(nsPresCon
   buttonRect.ISize(wm) = buttonISize;
 
   buttonRect.BStart(wm) = this->GetLogicalUsedBorder(wm).BStart(wm);
   buttonRect.BSize(wm) = mDisplayFrame->BSize(wm) +
                          this->GetLogicalUsedPadding(wm).BStartEnd(wm);
 
   mButtonFrame->SetRect(buttonRect, containerSize);
 
-  if (!NS_INLINE_IS_BREAK_BEFORE(aStatus) &&
+  if (!aStatus.IsInlineBreakBefore() &&
       !aStatus.IsFullyComplete()) {
     // This frame didn't fit inside a fragmentation container.  Splitting
     // a nsComboboxControlFrame makes no sense, so we override the status here.
     aStatus = NS_FRAME_COMPLETE;
   }
 }
 
 //--------------------------------------------------------------
--- a/layout/generic/nsBlockFrame.cpp
+++ b/layout/generic/nsBlockFrame.cpp
@@ -255,17 +255,17 @@ RecordReflowStatus(bool aChildIsBlock, n
   // 0: child-is-block
   // 1: child-is-inline
   int index = 0;
   if (!aChildIsBlock) index |= 1;
 
   // Compute new status
   uint32_t newS = record[index];
   if (NS_INLINE_IS_BREAK(aFrameReflowStatus)) {
-    if (NS_INLINE_IS_BREAK_BEFORE(aFrameReflowStatus)) {
+    if (aFrameReflowStatus.IsInlineBreakBefore()) {
       newS |= 1;
     }
     else if (aFrameReflowStatus.IsIncomplete()) {
       newS |= 2;
     }
     else {
       newS |= 4;
     }
@@ -1663,17 +1663,17 @@ nsBlockFrame::ComputeFinalSize(const Ref
     if (aState.mReflowStatus.IsIncomplete()) {
       // Overflow containers can only be overflow complete.
       // Note that auto height overflow containers have no normal children
       NS_ASSERTION(finalSize.BSize(wm) == 0,
                    "overflow containers must be zero-block-size");
       aState.mReflowStatus.SetOverflowIncomplete();
     }
   } else if (aReflowInput.AvailableBSize() != NS_UNCONSTRAINEDSIZE &&
-             !NS_INLINE_IS_BREAK_BEFORE(aState.mReflowStatus) &&
+             !aState.mReflowStatus.IsInlineBreakBefore() &&
              aState.mReflowStatus.IsComplete()) {
     // Currently only used for grid items, but could be used in other contexts.
     // The FragStretchBSizeProperty is our expected non-fragmented block-size
     // we should stretch to (for align-self:stretch etc).  In some fragmentation
     // cases though, the last fragment (this frame since we're complete), needs
     // to have extra size applied because earlier fragments consumed too much of
     // our computed size due to overflowing their containing block.  (E.g. this
     // ensures we fill the last row when a multi-row grid item is fragmented).
@@ -3574,17 +3574,17 @@ nsBlockFrame::ReflowBlockFrame(BlockRefl
                    "we need to call PositionChildViews");
       return;
     }
 
 #if defined(REFLOW_STATUS_COVERAGE)
     RecordReflowStatus(true, frameReflowStatus);
 #endif
 
-    if (NS_INLINE_IS_BREAK_BEFORE(frameReflowStatus)) {
+    if (frameReflowStatus.IsInlineBreakBefore()) {
       // None of the child block fits.
       *aKeepReflowGoing = false;
       if (ShouldAvoidBreakInside(aState.mReflowInput)) {
         aState.mReflowStatus.SetInlineLineBreakBeforeAndReset();
       } else {
         PushLines(aState, aLine.prev());
         aState.mReflowStatus.SetIncomplete();
       }
@@ -4073,17 +4073,17 @@ nsBlockFrame::DoReflowInlineFrames(Block
     // if the new Y coordinate is past the end of the block then
     // push the line and return now instead of later on after we are
     // past the float.
   }
   else if (LineReflowStatus::Truncated != lineReflowStatus &&
            LineReflowStatus::RedoNoPull != lineReflowStatus) {
     // If we are propagating out a break-before status then there is
     // no point in placing the line.
-    if (!NS_INLINE_IS_BREAK_BEFORE(aState.mReflowStatus)) {
+    if (!aState.mReflowStatus.IsInlineBreakBefore()) {
       if (!PlaceLine(aState, aLineLayout, aLine, aFloatStateBeforeLine,
                      aFloatAvailableSpace.mRect, aAvailableSpaceBSize,
                      aKeepReflowGoing)) {
         lineReflowStatus = LineReflowStatus::RedoMoreFloats;
         // PlaceLine already called GetAvailableSpaceForBSize for us.
       }
     }
   }
@@ -4187,17 +4187,17 @@ nsBlockFrame::ReflowInlineFrame(BlockRef
     // minimal amount of break we do).
     *aLineReflowStatus = LineReflowStatus::Stop;
 
     // XXX what should aLine's break-type be set to in all these cases?
     StyleClear breakType = frameReflowStatus.BreakType();
     MOZ_ASSERT(StyleClear::None != breakType ||
                StyleClear::None != aState.mFloatBreakType, "bad break type");
 
-    if (NS_INLINE_IS_BREAK_BEFORE(frameReflowStatus)) {
+    if (frameReflowStatus.IsInlineBreakBefore()) {
       // Break-before cases.
       if (aFrame == aLine->mFirstChild) {
         // If we break before the first frame on the line then we must
         // be trying to place content where there's no room (e.g. on a
         // line with wide floats). Inform the caller to reflow the
         // line after skipping past a float.
         *aLineReflowStatus = LineReflowStatus::RedoNextBand;
       }
--- a/layout/generic/nsBlockReflowContext.cpp
+++ b/layout/generic/nsBlockReflowContext.cpp
@@ -302,17 +302,17 @@ nsBlockReflowContext::ReflowBlock(const 
   mMetrics.BSize(mWritingMode) = nscoord(0xdeadbeef);
 #endif
 
   mOuterReflowInput.mFloatManager->Translate(tI, tB);
   mFrame->Reflow(mPresContext, mMetrics, aFrameRI, aFrameReflowStatus);
   mOuterReflowInput.mFloatManager->Translate(-tI, -tB);
 
 #ifdef DEBUG
-  if (!NS_INLINE_IS_BREAK_BEFORE(aFrameReflowStatus)) {
+  if (!aFrameReflowStatus.IsInlineBreakBefore()) {
     if ((CRAZY_SIZE(mMetrics.ISize(mWritingMode)) ||
          CRAZY_SIZE(mMetrics.BSize(mWritingMode))) &&
         !mFrame->GetParent()->IsCrazySizeAssertSuppressed()) {
       printf("nsBlockReflowContext: ");
       nsFrame::ListTag(stdout, mFrame);
       printf(" metrics=%d,%d!\n",
              mMetrics.ISize(mWritingMode), mMetrics.BSize(mWritingMode));
     }
@@ -325,17 +325,17 @@ nsBlockReflowContext::ReflowBlock(const 
     }
   }
 #endif
 
   if (!mFrame->HasOverflowAreas()) {
     mMetrics.SetOverflowAreasToDesiredBounds();
   }
 
-  if (!NS_INLINE_IS_BREAK_BEFORE(aFrameReflowStatus) ||
+  if (!aFrameReflowStatus.IsInlineBreakBefore() ||
       (mFrame->GetStateBits() & NS_FRAME_OUT_OF_FLOW)) {
     // If frame is complete and has a next-in-flow, we need to delete
     // them now. Do not do this when a break-before is signaled because
     // the frame is going to get reflowed again (and may end up wanting
     // a next-in-flow where it ends up), unless it is an out of flow frame.
     if (aFrameReflowStatus.IsFullyComplete()) {
       nsIFrame* kidNextInFlow = mFrame->GetNextInFlow();
       if (nullptr != kidNextInFlow) {
--- a/layout/generic/nsContainerFrame.cpp
+++ b/layout/generic/nsContainerFrame.cpp
@@ -1024,17 +1024,17 @@ nsContainerFrame::ReflowChild(nsIFrame* 
     PositionChildViews(aKidFrame);
   }
 
   // Reflow the child frame
   aKidFrame->Reflow(aPresContext, aDesiredSize, aReflowInput, aStatus);
 
   // If the child frame is complete, delete any next-in-flows,
   // but only if the NO_DELETE_NEXT_IN_FLOW flag isn't set.
-  if (!NS_INLINE_IS_BREAK_BEFORE(aStatus) &&
+  if (!aStatus.IsInlineBreakBefore() &&
       aStatus.IsFullyComplete() &&
       !(aFlags & NS_FRAME_NO_DELETE_NEXT_IN_FLOW_CHILD)) {
     nsIFrame* kidNextInFlow = aKidFrame->GetNextInFlow();
     if (kidNextInFlow) {
       // Remove all of the childs next-in-flows. Make sure that we ask
       // the right parent to do the removal (it's possible that the
       // parent is not this because we are executing pullup code)
       nsOverflowContinuationTracker::AutoFinish fini(aTracker, aKidFrame);
--- a/layout/generic/nsFirstLetterFrame.cpp
+++ b/layout/generic/nsFirstLetterFrame.cpp
@@ -260,17 +260,17 @@ nsFirstLetterFrame::Reflow(nsPresContext
       aMetrics.SetBlockStartAscent(kidMetrics.BlockStartAscent() +
                                    bp.BStart(wm));
       aMetrics.BSize(lineWM) = kidMetrics.BSize(lineWM) + bp.BStartEnd(wm);
     } else {
       nsLayoutUtils::SetBSizeFromFontMetrics(this, aMetrics, bp, lineWM, wm);
     }
   }
 
-  if (!NS_INLINE_IS_BREAK_BEFORE(aReflowStatus)) {
+  if (!aReflowStatus.IsInlineBreakBefore()) {
     // Create a continuation or remove existing continuations based on
     // the reflow completion status.
     if (aReflowStatus.IsComplete()) {
       if (aReflowInput.mLineLayout) {
         aReflowInput.mLineLayout->SetFirstLetterStyleOK(false);
       }
       nsIFrame* kidNextInFlow = kid->GetNextInFlow();
       if (kidNextInFlow) {
--- a/layout/generic/nsGridContainerFrame.cpp
+++ b/layout/generic/nsGridContainerFrame.cpp
@@ -5620,26 +5620,26 @@ nsGridContainerFrame::ReflowRowsInFragme
     // Pass along how much to stretch this fragment, in case it's needed.
     nscoord bSize =
       aState.mRows.GridLineEdge(std::min(aEndRow, info->mArea.mRows.mEnd),
                                 GridLineSide::eBeforeGridGap) -
       aState.mRows.GridLineEdge(std::max(aStartRow, row),
                                 GridLineSide::eAfterGridGap);
     ReflowInFlowChild(child, info, aContainerSize, Some(bSize), &aFragmentainer,
                       aState, aContentArea, aDesiredSize, childStatus);
-    MOZ_ASSERT(NS_INLINE_IS_BREAK_BEFORE(childStatus) ||
+    MOZ_ASSERT(childStatus.IsInlineBreakBefore() ||
                !childStatus.IsFullyComplete() ||
                !child->GetNextInFlow(),
                "fully-complete reflow should destroy any NIFs");
 
-    if (NS_INLINE_IS_BREAK_BEFORE(childStatus)) {
+    if (childStatus.IsInlineBreakBefore()) {
       MOZ_ASSERT(!child->GetPrevInFlow(),
                  "continuations should never report BREAK_BEFORE status");
       MOZ_ASSERT(!aFragmentainer.mIsTopOfPage,
-                 "got NS_INLINE_IS_BREAK_BEFORE at top of page");
+                 "got IsInlineBreakBefore() at top of page");
       if (!didGrowRow) {
         if (rowCanGrow) {
           // Grow this row and restart with the next row as |aEndRow|.
           aState.mRows.ResizeRow(row, maxRowSize);
           if (aState.mSharedGridData) {
             aState.mSharedGridData->mRows.ResizeRow(row, maxRowSize);
           }
           didGrowRow = true;
--- a/layout/generic/nsIFrame.h
+++ b/layout/generic/nsIFrame.h
@@ -317,16 +317,17 @@ public:
     }
   }
 
   // mInlineBreak bit flag means a break is requested.
 
   // Suppose a break is requested. When mInlineBreakAfter is set, the break
   // should occur after the frame just reflowed; when mInlineBreakAfter is
   // clear, the break should occur before the frame just reflowed.
+  bool IsInlineBreakBefore() const { return mInlineBreak && !mInlineBreakAfter; }
   StyleClear BreakType() const { return mBreakType; }
 
   // Set the inline line-break-before status, and reset other bit flags. The
   // break type is StyleClear::Line. Note that other frame completion status
   // isn't expected to matter after calling this method.
   void SetInlineLineBreakBeforeAndReset() {
     Reset();
     mBreakType = StyleClear::Line;
@@ -372,19 +373,16 @@ private:
 // Macros that use those bits
 
 #define NS_INLINE_IS_BREAK(_status) \
   (0 != ((_status) & NS_INLINE_BREAK))
 
 #define NS_INLINE_IS_BREAK_AFTER(_status) \
   (0 != ((_status) & NS_INLINE_BREAK_AFTER))
 
-#define NS_INLINE_IS_BREAK_BEFORE(_status) \
-  (NS_INLINE_BREAK == ((_status) & (NS_INLINE_BREAK|NS_INLINE_BREAK_AFTER)))
-
 #define NS_FRAME_SET_TRUNCATION(aStatus, aReflowInput, aMetrics) \
   aStatus.UpdateTruncated(aReflowInput, aMetrics);
 
 //----------------------------------------------------------------------
 
 /**
  * DidReflow status values.
  */
--- a/layout/generic/nsInlineFrame.cpp
+++ b/layout/generic/nsInlineFrame.cpp
@@ -798,18 +798,18 @@ nsInlineFrame::ReflowInlineFrame(nsPresC
                                  InlineReflowInput& irs,
                                  nsIFrame* aFrame,
                                  nsReflowStatus& aStatus)
 {
   nsLineLayout* lineLayout = aReflowInput.mLineLayout;
   bool reflowingFirstLetter = lineLayout->GetFirstLetterStyleOK();
   bool pushedFrame;
   lineLayout->ReflowFrame(aFrame, aStatus, nullptr, pushedFrame);
-  
-  if (NS_INLINE_IS_BREAK_BEFORE(aStatus)) {
+
+  if (aStatus.IsInlineBreakBefore()) {
     if (aFrame != mFrames.FirstChild()) {
       // Change break-before status into break-after since we have
       // already placed at least one child frame. This preserves the
       // break-type so that it can be propagated upward.
       StyleClear oldBreakType = aStatus.BreakType();
       aStatus.Reset();
       aStatus.SetIncomplete();
       aStatus.SetInlineLineBreakAfter(oldBreakType);
--- a/layout/generic/nsLineLayout.cpp
+++ b/layout/generic/nsLineLayout.cpp
@@ -1023,17 +1023,17 @@ nsLineLayout::ReflowFrame(nsIFrame* aFra
   }
   if (reflowOutput.BSize(lineWM) < 0) {
     reflowOutput.BSize(lineWM) = 0;
   }
 
 #ifdef DEBUG
   // Note: break-before means ignore the reflow metrics since the
   // frame will be reflowed another time.
-  if (!NS_INLINE_IS_BREAK_BEFORE(aReflowStatus)) {
+  if (!aReflowStatus.IsInlineBreakBefore()) {
     if ((CRAZY_SIZE(reflowOutput.ISize(lineWM)) ||
          CRAZY_SIZE(reflowOutput.BSize(lineWM))) &&
         !LineContainerFrame()->GetParent()->IsCrazySizeAssertSuppressed()) {
       printf("nsLineLayout: ");
       nsFrame::ListTag(stdout, aFrame);
       printf(" metrics=%d,%d!\n", reflowOutput.Width(), reflowOutput.Height());
     }
     if ((reflowOutput.Width() == nscoord(0xdeadbeef)) ||
@@ -1062,17 +1062,17 @@ nsLineLayout::ReflowFrame(nsIFrame* aFra
   aFrame->DidReflow(mPresContext,
                     isText ? nullptr : reflowInputHolder.ptr(),
                     nsDidReflowStatus::FINISHED);
 
   if (aMetrics) {
     *aMetrics = reflowOutput;
   }
 
-  if (!NS_INLINE_IS_BREAK_BEFORE(aReflowStatus)) {
+  if (!aReflowStatus.IsInlineBreakBefore()) {
     // If frame is complete and has a next-in-flow, we need to delete
     // them now. Do not do this when a break-before is signaled because
     // the frame is going to get reflowed again (and may end up wanting
     // a next-in-flow where it ends up).
     if (aReflowStatus.IsComplete()) {
       nsIFrame* kidNextInFlow = aFrame->GetNextInFlow();
       if (nullptr != kidNextInFlow) {
         // Remove all of the childs next-in-flows. Make sure that we ask
--- a/layout/generic/nsRubyBaseContainerFrame.cpp
+++ b/layout/generic/nsRubyBaseContainerFrame.cpp
@@ -399,19 +399,19 @@ nsRubyBaseContainerFrame::Reflow(nsPresC
   // container could be non-zero because of non-empty ruby annotations.
   // XXX When bug 765861 gets fixed, this warning should be upgraded.
   NS_WARNING_ASSERTION(
     NS_INLINE_IS_BREAK(aStatus) || isize == lineSpanSize || mFrames.IsEmpty(),
     "bad isize");
 
   // If there exists any span, the columns must either be completely
   // reflowed, or be not reflowed at all.
-  MOZ_ASSERT(NS_INLINE_IS_BREAK_BEFORE(aStatus) ||
+  MOZ_ASSERT(aStatus.IsInlineBreakBefore() ||
              aStatus.IsComplete() || !hasSpan);
-  if (!NS_INLINE_IS_BREAK_BEFORE(aStatus) &&
+  if (!aStatus.IsInlineBreakBefore() &&
       aStatus.IsComplete() && hasSpan) {
     // Reflow spans
     RubyReflowInput reflowInput = {
       false, false, textContainers, aReflowInput, reflowInputs
     };
     nscoord spanISize = ReflowSpans(reflowInput);
     isize = std::max(isize, spanISize);
   }
@@ -475,17 +475,17 @@ nsRubyBaseContainerFrame::ReflowColumns(
 
   uint32_t columnIndex = 0;
   RubyColumn column;
   column.mTextFrames.SetCapacity(rtcCount);
   RubyColumnEnumerator e(this, aReflowInput.mTextContainers);
   for (; !e.AtEnd(); e.Next()) {
     e.GetColumn(column);
     icoord += ReflowOneColumn(aReflowInput, columnIndex, column, reflowStatus);
-    if (!NS_INLINE_IS_BREAK_BEFORE(reflowStatus)) {
+    if (!reflowStatus.IsInlineBreakBefore()) {
       columnIndex++;
     }
     if (NS_INLINE_IS_BREAK(reflowStatus)) {
       break;
     }
     // We are not handling overflow here.
     MOZ_ASSERT(reflowStatus == NS_FRAME_COMPLETE);
   }
@@ -499,33 +499,33 @@ nsRubyBaseContainerFrame::ReflowColumns(
     // Try pull some frames from next continuations. This call replaces
     // frames in |column| with the frame pulled in each level.
     PullOneColumn(lineLayout, pullFrameState, column, isComplete);
     if (isComplete) {
       // No more frames can be pulled.
       break;
     }
     icoord += ReflowOneColumn(aReflowInput, columnIndex, column, reflowStatus);
-    if (!NS_INLINE_IS_BREAK_BEFORE(reflowStatus)) {
+    if (!reflowStatus.IsInlineBreakBefore()) {
       columnIndex++;
     }
   }
 
   if (!e.AtEnd() && NS_INLINE_IS_BREAK_AFTER(reflowStatus)) {
     // The current column has been successfully placed.
     // Skip to the next column and mark break before.
     e.Next();
     e.GetColumn(column);
     reflowStatus.SetInlineLineBreakBeforeAndReset();
   }
   if (!e.AtEnd() || (GetNextInFlow() && !isComplete)) {
     aStatus.SetIncomplete();
   }
 
-  if (NS_INLINE_IS_BREAK_BEFORE(reflowStatus)) {
+  if (reflowStatus.IsInlineBreakBefore()) {
     if (!columnIndex || !aReflowInput.mAllowLineBreak) {
       // If no column has been placed yet, or we have any span,
       // the whole container should be in the next line.
       aStatus.SetInlineLineBreakBeforeAndReset();
       return 0;
     }
     aStatus.SetInlineLineBreakAfter();
     MOZ_ASSERT(aStatus.IsComplete() || aReflowInput.mAllowLineBreak);
--- a/layout/generic/nsRubyFrame.cpp
+++ b/layout/generic/nsRubyFrame.cpp
@@ -200,17 +200,17 @@ nsRubyFrame::ReflowSegment(nsPresContext
   AutoRubyTextContainerArray textContainers(aBaseContainer);
   const uint32_t rtcCount = textContainers.Length();
 
   ReflowOutput baseMetrics(aReflowInput);
   bool pushedFrame;
   aReflowInput.mLineLayout->ReflowFrame(aBaseContainer, aStatus,
                                         &baseMetrics, pushedFrame);
 
-  if (NS_INLINE_IS_BREAK_BEFORE(aStatus)) {
+  if (aStatus.IsInlineBreakBefore()) {
     if (aBaseContainer != mFrames.FirstChild()) {
       // Some segments may have been reflowed before, hence it is not
       // a break-before for the ruby container.
       aStatus.Reset();
       aStatus.SetInlineLineBreakAfter();
       aStatus.SetIncomplete();
       PushChildren(aBaseContainer, aBaseContainer->GetPrevSibling());
       aReflowInput.mLineLayout->SetDirtyNextLine();
--- a/layout/reftests/css-grid/grid-fragmentation-006-ref.html
+++ b/layout/reftests/css-grid/grid-fragmentation-006-ref.html
@@ -42,17 +42,17 @@ i { display:block; height:10px; margin-t
 .t { border-bottom-width:0; }
 .b { border-top-width:0; }
 .br1 { height:94px; border-width:5px; border-top-style:solid; }
 
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 110px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 110px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:30px; background:grey">
 <div class="grid">
 <span><i></i><i></i><i></i><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
 <div class="columns" style="height: 70px/*item will be INCOMPLETE*/">
 <div style="background:grey">
@@ -63,51 +63,51 @@ i { display:block; height:10px; margin-t
 
 <div class="columns" style="height: 100px/*item will be INCOMPLETE*/">
 <div style="background:grey">
 <div class="grid">
 <span style="grid-row:span 2"><i></i><i></i><i></i><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 140px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 140px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:30px; background:grey">
 <div class="grid">
 <span style="grid-row:span 3"><x></x></span>
 <span style="grid-row:span 2"><i></i><i></i><i></i><i></i><i></i><i></i><i></i><i></i><i></i><x></x></span></div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid t" style="grid-auto-rows: 50px; height:50px;">
 <span class="t" style="grid-row:span 2; height:49px; overflow:hidden"><i></i><i></i><i></i><x></x></span>
 </div>
 <div style="height:44px"></div>
 <div class="grid b" style="grid-auto-rows: 50px; height:50px;">
 <span class="b" style="grid-row:span 2; height:11px; overflow:hidden"><i style="margin-top:0;height:2px"></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="br1"></div>
 <div class="grid b" style="grid-auto-rows: 50px; height:116px;">
 <span style="grid-row:span 2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="br1"></div>
 <div class="grid b" style="grid-auto-rows: 50px; height:116px; grid-gap:0;">
 <span style="grid-row:span 2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="br1"></div>
 <div class="grid b" style="grid-auto-rows: 50px; height:116px; grid-gap:0;">
 <span style="height:100px; background:pink"><x></x></span>
 <span style="grid-row:span 2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
--- a/layout/reftests/css-grid/grid-fragmentation-006.html
+++ b/layout/reftests/css-grid/grid-fragmentation-006.html
@@ -41,17 +41,17 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 110px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 110px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:30px; background:grey">
 <div class="grid">
 <span class="avoid-break"><i></i><i></i><i></i><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
 <div class="columns" style="height: 70px/*item will be INCOMPLETE*/">
 <div style="background:grey">
@@ -62,45 +62,45 @@ i { display:block; height:10px; margin-t
 
 <div class="columns" style="height: 100px/*item will be INCOMPLETE*/">
 <div style="background:grey">
 <div class="grid">
 <span class="avoid-break" style="grid-row:span 2"><i></i><i></i><i></i><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 140px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 140px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:30px; background:grey">
 <div class="grid">
 <span style="grid-row:span 3"><x></x></span>
 <span class="avoid-break" style="grid-row:span 2"><i></i><i></i><i></i><i></i><i></i><i></i><i></i><i></i><i></i><x></x></span></div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-auto-rows: 50px;">
 <span class="avoid-break" style="grid-row:span 2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-auto-rows: 50px; height:116px;">
 <span class="avoid-break" style="grid-row:span 2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-auto-rows: 50px; height:116px; grid-gap:0;">
 <span class="avoid-break" style="grid-row:span 2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-auto-rows: 50px; height:116px; grid-gap:0;">
 <span style="height:100px; background:pink"><x></x></span>
 <span class="avoid-break" style="grid-row:span 2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
 
--- a/layout/reftests/css-grid/grid-fragmentation-007.html
+++ b/layout/reftests/css-grid/grid-fragmentation-007.html
@@ -41,62 +41,62 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 1fr 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 1fr 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 1fr 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px 1fr 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px 1fr 50px;">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px 1fr 50px; grid-gap:0;">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
--- a/layout/reftests/css-grid/grid-fragmentation-019.html
+++ b/layout/reftests/css-grid/grid-fragmentation-019.html
@@ -42,62 +42,62 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 1fr 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 1fr 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 1fr 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px 1fr 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px 1fr 50px;">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px 1fr 50px; grid-gap:0;">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
--- a/layout/reftests/css-grid/grid-fragmentation-022.html
+++ b/layout/reftests/css-grid/grid-fragmentation-022.html
@@ -41,62 +41,62 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px min-content 50px; grid-gap:0;">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
--- a/layout/reftests/css-grid/grid-fragmentation-023.html
+++ b/layout/reftests/css-grid/grid-fragmentation-023.html
@@ -42,62 +42,62 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px min-content 50px; grid-gap:0;">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
--- a/layout/reftests/css-grid/grid-fragmentation-024.html
+++ b/layout/reftests/css-grid/grid-fragmentation-024.html
@@ -42,81 +42,81 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px min-content 50px; grid-gap:0;">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 <span style="grid-row:4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:5"><x></x></span>
 </div>
 </div></div>
--- a/layout/reftests/css-grid/grid-fragmentation-025.html
+++ b/layout/reftests/css-grid/grid-fragmentation-025.html
@@ -42,81 +42,81 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px min-content 50px; grid-gap:0;">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 <span style="grid-row:4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:5"><x></x></span>
 </div>
 </div></div>
--- a/layout/reftests/css-grid/grid-fragmentation-027.html
+++ b/layout/reftests/css-grid/grid-fragmentation-027.html
@@ -43,81 +43,81 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px min-content 50px; grid-gap:0;">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 <span style="grid-row:4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px;">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:5"><x></x></span>
 </div>
 </div></div>
--- a/layout/reftests/css-grid/grid-fragmentation-028.html
+++ b/layout/reftests/css-grid/grid-fragmentation-028.html
@@ -42,81 +42,81 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0; min-height:300px">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 2"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0; min-height:120px">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px; min-height:120px">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px; min-height:120px; max-height:100px">
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow row 2*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow row 2*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 50px min-content 50px; grid-gap:0; min-height:120px">
 <span style="grid-row:2/span 2"><x></x></span>
 <span style="grid-row:2; height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><i></i><i></i><i></i><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 50px; grid-gap:0;">
 <span style="height:50px"><i style="height:60px"></i><x></x></span>
 <span class="avoid-break" style="height:60px"><i></i><i></i><i></i><x></x></span>
 <span style="grid-row:1/span 4"><x></x></span>
 <span style="grid-row:4"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 5px min-content 50px; min-height:200px">
 <span style="grid-row:2; height:50px"><x></x><i style="height:60px"></i></span>
 <span class="avoid-break" style="grid-row:2; height:60px"><x></x><i></i><i></i><i></i></span>
 <span style="grid-row:1/span 5"><x></x></span>
 <span style="grid-row:5"><x></x></span>
 </div>
 </div></div>
--- a/layout/reftests/css-grid/grid-fragmentation-030-ref.html
+++ b/layout/reftests/css-grid/grid-fragmentation-030-ref.html
@@ -38,71 +38,71 @@ body { overflow:hidden; }
 span { background:lime; border:1px solid black; }
 x { display:block; height:20px; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:90px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:89px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:94px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:95px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:200px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:none;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"></span>
 </div>
 </div></div>
 
--- a/layout/reftests/css-grid/grid-fragmentation-030.html
+++ b/layout/reftests/css-grid/grid-fragmentation-030.html
@@ -41,71 +41,71 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; max-height:90px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; max-height:89px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; max-height:94px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; max-height:95px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; max-height:200px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; max-height:none;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"></span>
 </div>
 </div></div>
 
--- a/layout/reftests/css-grid/grid-fragmentation-031-ref.html
+++ b/layout/reftests/css-grid/grid-fragmentation-031-ref.html
@@ -41,72 +41,72 @@ x { display:block; height:20px; }
 .b { border-top-width:0; }
 .m { border-bottom-width:0; border-top-width:0; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid t" style="grid-template-rows: 94px; grid-gap:0; height:90px; max-height:90px; ">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 </div>
 <div style="height:4px"></div>
 <div class="grid b" style="height:0px;grid-template-rows: 10px;"><span></span></div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:89px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid t" style="grid-template-rows: 94px; grid-gap:0; height:94px; max-height:94px; ">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 </div>
 <div class="grid b" style="height:0px;grid-template-rows: 10px;"><span></span></div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0; max-height:95px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: 94px 10px; grid-gap:0;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid t" style="grid-template-rows: 94px; grid-gap:0; height:90px; max-height:90px; ">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 </div>
 <div style="height:4px"></div>
 <div class="grid b" style="height:0px;grid-template-rows: 10px;"><span></span></div>
 </div></div>
--- a/layout/reftests/css-grid/grid-fragmentation-031.html
+++ b/layout/reftests/css-grid/grid-fragmentation-031.html
@@ -41,71 +41,71 @@ span { background:lime; border:1px solid
 x { display:block; height:20px; }
 .avoid-break { page-break-inside:avoid; break-inside:avoid; }
 
 i { display:block; height:10px; margin-top:7px; background:blue; }
 </style>
 </head>
 <body>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; height:90px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; height:89px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; height:94px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; height:95px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; max-height:50px;">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"><x></x></span>
 </div>
 </div></div>
 
-<div class="columns" style="height: 100px/*trigger NS_INLINE_IS_BREAK_BEFORE for the item: grow the row*/">
+<div class="columns" style="height: 100px/*trigger IsInlineBreakBefore() for the item: grow the row*/">
 <div style="padding-top:1px; background:grey">
 <div class="grid" style="grid-template-rows: min-content 10px; grid-gap:0; min-height:90px">
 <span></span>
 <span class="avoid-break" style="height:60px"><i></i><x></x><i></i><x></x><i></i><x></x></span>
 <span style="grid-row:2;"></span>
 </div>
 </div></div>
 
--- a/layout/tables/nsTableFrame.cpp
+++ b/layout/tables/nsTableFrame.cpp
@@ -3166,17 +3166,17 @@ nsTableFrame::ReflowChildren(TableReflow
       if (isPaginated && !aStatus.IsFullyComplete() &&
           ShouldAvoidBreakInside(aReflowInput.reflowInput)) {
         aStatus.SetInlineLineBreakBeforeAndReset();
         break;
       }
       // see if the rowgroup did not fit on this page might be pushed on
       // the next page
       if (isPaginated &&
-          (NS_INLINE_IS_BREAK_BEFORE(aStatus) ||
+          (aStatus.IsInlineBreakBefore() ||
            (aStatus.IsComplete() &&
             (NS_UNCONSTRAINEDSIZE != kidReflowInput.AvailableHeight()) &&
             kidReflowInput.AvailableHeight() < desiredSize.Height()))) {
         if (ShouldAvoidBreakInside(aReflowInput.reflowInput)) {
           aStatus.SetInlineLineBreakBeforeAndReset();
           break;
         }
         // if we are on top of the page place with dataloss
--- a/layout/tables/nsTableRowGroupFrame.cpp
+++ b/layout/tables/nsTableRowGroupFrame.cpp
@@ -1206,17 +1206,17 @@ nsTableRowGroupFrame::SplitRowGroup(nsPr
         }
         else {
           // The row frame is complete because either (1) its minimum height is greater than the
           // available height we gave it, or (2) it may have been given a larger height through
           // style than its content, or (3) it contains a rowspan >1 cell which hasn't been
           // reflowed with a constrained height yet (we will find out when SplitSpanningCells is
           // called below)
           if (rowMetrics.Height() > availSize.height ||
-              (NS_INLINE_IS_BREAK_BEFORE(aStatus) && !aRowForcedPageBreak)) {
+              (aStatus.IsInlineBreakBefore() && !aRowForcedPageBreak)) {
             // cases (1) and (2)
             if (isTopOfPage) {
               // We're on top of the page, so keep the row on this page. There will be data loss.
               // Push the row frame that follows
               nsTableRowFrame* nextRowFrame = rowFrame->GetNextRow();
               if (nextRowFrame) {
                 aStatus = NS_FRAME_NOT_COMPLETE;
               }
--- a/layout/generic/BlockReflowInput.cpp
+++ b/layout/generic/BlockReflowInput.cpp
@@ -915,26 +915,26 @@ BlockReflowInput::FlowAndPlaceFloat(nsIF
   if (reflowStatus.IsIncomplete())
     floatMargin.BEnd(wm) = 0;
 
   // In the case that we're in columns and not splitting floats, we need
   // to check here that the float's height fit, and if it didn't, bail.
   // (controlled by the pref "layout.float-fragments-inside-column.enabled")
   //
   // Likewise, if none of the float fit, and it needs to be pushed in
   // its entirety to the next page (IsTruncated() or
   // NS_INLINE_IS_BREAK_BEFORE), we need to do the same.
   if ((ContentBSize() != NS_UNCONSTRAINEDSIZE &&
        !mFlags.mFloatFragmentsInsideColumnEnabled &&
        adjustedAvailableSpace.BSize(wm) == NS_UNCONSTRAINEDSIZE &&
        !mustPlaceFloat &&
        aFloat->BSize(wm) + floatMargin.BStartEnd(wm) >
        ContentBEnd() - floatPos.B(wm)) ||
       reflowStatus.IsTruncated() ||
-      NS_INLINE_IS_BREAK_BEFORE(reflowStatus)) {
+      reflowStatus.IsInlineBreakBefore()) {
     PushFloatPastBreak(aFloat);
     return false;
   }
@@ -915,26 +915,26 @@ BlockReflowInput::FlowAndPlaceFloat(nsIF
   //
   // Likewise, if none of the float fit, and it needs to be pushed in
-  // its entirety to the next page (IsTruncated() or
-  // NS_INLINE_IS_BREAK_BEFORE), we need to do the same.
+  // its entirety to the next page (IsTruncated() or IsInlineBreakBefore()),
+  // we need to do the same.
   if ((ContentBSize() != NS_UNCONSTRAINEDSIZE &&
        !mFlags.mFloatFragmentsInsideColumnEnabled &&
 
   // We can't use aFloat->ShouldAvoidBreakInside(mReflowInput) here since
   // its mIsTopOfPage may be true even though the float isn't at the
   // top when floatPos.B(wm) > 0.
   if (ContentBSize() != NS_UNCONSTRAINEDSIZE &&